
.. blogpost::
    :title: A few interested modules not included in this one
    :keywords: install, wordcloud, ORM, images, cluster, HMM
    :date: 2015-12-05
    :categories: install, module

    The following might be included in a near future.

    * `gvar <http://pythonhosted.org/gvar/>`_: functionalities about gaussian random variables
    * `hmmlearn <http://hmmlearn.github.io/hmmlearn/>`_:
      `Hidden Markov Models <https://en.wikipedia.org/wiki/Hidden_Markov_model>`_, see also
      `seqlearn <http://larsmans.github.io/seqlearn/>`_ (added in 2016/03)
    * `menpo <http://www.menpo.org/>`_: functionalities for images, rotation, homothetic transformation,
      landmark detection
    * `minepy <http://minepy.sourceforge.net/>`_: Maximal Information-based Nonparametric Exploration,
      see `Maximal information coefficient <https://en.wikipedia.org/wiki/Maximal_information_coefficient>`_
    * `peewee <http://docs.peewee-orm.com/en/latest/>`_: Python implementation of ORM or
      `Object Relational Mapping <https://en.wikipedia.org/wiki/Object-relational_mapping>`_,
      see also `Pony <https://ponyorm.com/>`_,
      `playhouse <http://docs.peewee-orm.com/en/latest/peewee/playhouse.html>`_
    * `scikit-fmm  <https://github.com/scikit-fmm/scikit-fmm>`_: to solve equations about waves
    * `scons <http://www.scons.org/>`_:  a module to generate makefile or file *csproj* or *sln* for
      `Visual Studio <https://www.visualstudio.com/>`_.
